@@ -11,6 +11,10 @@ double const_cost_worker(const NumericVector &y, const NumericVector &w,
   if(j <= (i + (min_seg-1))) {
     return std::numeric_limits<double>::max();
   }
+  const int vlen = y.length();
+  if((i<0) || (j>=vlen) || (vlen!=w.length()) || (min_seg<1)) {
+    throw std::range_error("Inadmissible value");
+  }
   double w_ij = 0;
   double sum_ij = 0;
   for(int k=i; k<=j; ++k) {
@@ -34,7 +38,7 @@ double const_cost_worker(const NumericVector &y, const NumericVector &w,
 //' 
 //' @param y NumericVector, values to group in order.
 //' @param w NumericVector, weights.
-//' @param min_seg positive integer, minimum segment size.
+//' @param min_seg positive integer, minimum segment size (>=1).
 //' @param i integer, first index (inclusive).
 //' @param j integer, j>=i last index (inclusive);
 //' @return scalar, const cost of [i,...,j] interval (inclusive).
@@ -60,7 +64,7 @@ double const_cost(NumericVector y, NumericVector w,
 //' 
 //' @param y NumericVector, values to group in order.
 //' @param w NumericVector, weights.
-//' @param min_seg positive integer, minimum segment size.
+//' @param min_seg positive integer, minimum segment size (>=1).
 //' @param indices IntegerVector, order list of indices to pair.
 //' @return xcosts NumericMatix, for j>=i xcosts(i,j) is the cost of partition element [i,...,j] (inclusive).
 //' 
@@ -74,6 +78,10 @@ double const_cost(NumericVector y, NumericVector w,
 NumericMatrix const_costs(NumericVector y, NumericVector w, 
                           const int min_seg,
                           IntegerVector indices) {
+  const int vlen = y.length();
+  if(vlen!=w.length() || (min_seg<1)) {
+    throw std::range_error("Inadmissible value");
+  }
   const int n = indices.size();
   NumericMatrix xcosts = NumericMatrix(n, n);
   const double single_value = std::numeric_limits<double>::max();
